@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.h 2440 2007-06-26 17:22:04Z svn $
+ * $Id: DownloadFlowController.h 2467 2007-06-30 02:57:59Z svn $
  *****************************************************************************/
 
 #ifndef DOWNLOAD_FLOW_CONTROLLER_H
@@ -94,14 +94,11 @@ public:
             flow_controller_->remove_session(sockaddr_);
         }
     };
+    bool is_valid();
 
-    bool is_valid() {
-        if (!is_valid_) {
-            is_valid_ = flow_controller_->add_session(sockaddr_);
-        }
-        return is_valid_;
-    };
 private:
+    static const apr_size_t DOWNLOAD_BUSY_SLEEP_SEC;
+
     DownloadFlowController *flow_controller_;
     apr_sockaddr_t *sockaddr_;
     bool is_valid_;
