@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadLocker.h 2525 2007-07-12 15:23:44Z svn $
+ * $Id: ReadLocker.h 2525M 2007-08-26 12:58:57Z (ローカル) $
  *****************************************************************************/
 
 #ifndef READ_LOCKER_H
@@ -54,6 +54,9 @@ public:
 
         try_count = 1;
         while (1) {
+            // curr_status の read がループ外に押し出されるのを防ぐ
+            MEMORY_BARRIER;
+
             curr_status = apr_atomic_read(lock);
             if (LIKELY(can_lock(curr_status))) {
                 new_status = curr_status + READ_COUNT_UINIT;
@@ -92,6 +95,9 @@ public:
         lock = lock_;
         try_count = 1;
         while (1) {
+            // curr_status の read がループ外に押し出されるのを防ぐ
+            MEMORY_BARRIER;
+
             curr_status = apr_atomic_read(lock);
             if (UNLIKELY(is_timeout(curr_status, status_))) {
                 // 他のスレッドにてタイムアウト処理がされた
