@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: UploadItem.h 2290M 2007-08-19 14:23:49Z (ローカル) $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_H
@@ -98,9 +98,10 @@ public:
     {
         return header_.index;
     }
-    apr_size_t get_download_count()
+    apr_size_t get_download_count() const
     {
-        return  apr_atomic_read(&(header_.download_count));
+        return  apr_atomic_read
+            (const_cast<apr_atomic_t *>(&(header_.download_count)));
     }
     apr_uint64_t get_file_size() const
     {
@@ -215,6 +216,7 @@ public:
                                     const char *download_pass="",
                                     const char *comment="",
                                     bool is_need_validate=true);
+    static int cmp_download_count(const UploadItem *a, const UploadItem *b);
 
 private:
     /**
