@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemIterator.h 2548 2007-08-06 14:16:57Z svn $
+ * $Id: UploadItemIterator.h 2548M 2007-08-19 14:35:41Z (ローカル) $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_ITERATOR_H
@@ -47,6 +47,18 @@ class UploadItemList;
 class UploadItemIterator: public Uncopyable
 {
 public:
+    /**
+     * コンストラクタです．
+     *
+     * @param[in] pool プール
+     * @param[in] item_manager アイテムマネージャ
+     * @param[in] start_index 開始インデックス
+     * @param[in] end_index 終了インデックス
+     * @param[in] cmp ソートに利用する比較関数
+     */
+    UploadItemIterator(apr_pool_t *pool, UploadItemManager *item_manager,
+                       apr_size_t start_index, apr_size_t end_index,
+                       int(*cmp)(const void *a, const void *b));
     /**
      * コンストラクタです．
      *
@@ -91,6 +103,9 @@ public:
     };
 
 private:
+    void init(apr_pool_t *pool, UploadItemList *item_list,
+              apr_size_t start_index, apr_size_t end_index,
+              int(*cmp)(const void *a, const void *b));
     void init(apr_pool_t *pool, UploadItemList *item_list,
               apr_size_t start_index, apr_size_t end_index);
     void validate_index(UploadItemList *item_list,
