@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.h 2485 2007-07-03 15:30:09Z svn $
+ * $Id: UploadItemManager.h 2508 2007-07-06 22:47:18Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_MANAGER_H
@@ -38,9 +38,10 @@
 
 #include "Uncopyable.h"
 
-
 class UploadItemList;
+class UploadItemIterator;
 class ThumbnailList;
+class ThumbnailIterator;
 
 /**
  * @brief BBS のスレッドを管理するクラス．
@@ -163,6 +164,9 @@ private:
      */
     void sync_all_item_by_catches(apr_pool_t *pool);
 
+    friend class UploadItemIterator;
+    friend class ThumbnailIterator;
+
     apr_pool_t *pool_;
 
     const char *data_dir_path_;
@@ -173,10 +177,10 @@ private:
 
     UploadItemList *item_list_;
     ThumbnailList *thumbnail_list_;
-    /** 最終更新時刻 (in in 共有メモリ) */
-    apr_time_t *mtime_;
     /** マネージャのロック (in in 共有メモリ) */
     apr_atomic_t *lock_;
+    /** 最終更新時刻 (in in 共有メモリ) */
+    apr_time_t *mtime_;
     /** 変更カウンタ (in in 共有メモリ) */
     apr_size_t *age_;
 };
