@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: WriteLocker.h 2513 2007-07-09 13:05:22Z svn $
+ * $Id: WriteLocker.h 2525M 2007-08-26 12:59:14Z (ローカル) $
  *****************************************************************************/
 
 #ifndef WRITE_LOCKER_H
@@ -45,38 +45,39 @@ public:
     /**
      * コンストラクタです．
      *
-     * @param[out] lock ロック変数
+     * @param[in] lock ロック変数
      */
     WriteLocker(apr_atomic_t *lock)
-      : ReadWriteLocker(lock)
+      : ReadWriteLocker()
     {
         apr_size_t try_count;
         apr_uint32_t curr_status;
         apr_uint32_t new_status;
+        apr_uint32_t prev_status;
 
-        try_count = 0;
+        try_count = 1;
         while (1) {
-            try_count++;
+            // curr_status の read がループ外に押し出されるのを防ぐ
+            MEMORY_BARRIER;
 
             curr_status = apr_atomic_read(lock);
             if (get_read_count(curr_status) == NOT_LOCKED) {
                 new_status = curr_status | WRITE_LOCKED;
-                status_ = new_status; // 先に更新しておく
-                if (apr_atomic_cas(lock, new_status, curr_status) ==
-                    curr_status) {
+                prev_status = apr_atomic_cas(lock, new_status, curr_status);
+                init(lock, new_status);
+                if (prev_status == curr_status) {
                     log_try_count("WriteLock",
                                   try_count, curr_status, new_status);
                     return;
                 }
             } else {
-                if (((try_count & TIMEOUT_CHECK_MASK) == 0) &&
+                if (((try_count++ & TIMEOUT_CHECK_MASK) == 0) &&
                     should_timeout(curr_status)) {
                     // タイムアウトしたら age を増やす
-                    new_status = ((curr_status | WRITE_LOCKED) + AGE_UINIT) &
-                        VALID_MASK;
-                    status_ = new_status; // 先に更新しておく
-                    if (apr_atomic_cas(lock, new_status, curr_status) ==
-                        curr_status) {
+                    new_status = (curr_status | WRITE_LOCKED) + AGE_UINIT;
+                    prev_status = apr_atomic_cas(lock, new_status, curr_status);
+                    init(lock, new_status);
+                    if (prev_status == curr_status) {
                         log_try_count("WriteLock(TIME OUT)",
                                       try_count, curr_status, new_status);
                         return;
@@ -85,7 +86,7 @@ public:
 
                 if (get_wait_write(curr_status) != WAIT_WRITE) {
                     new_status = curr_status | WAIT_WRITE;
-                    (void)apr_atomic_cas(lock_, new_status, curr_status);
+                    (void)apr_atomic_cas(lock, new_status, curr_status);
                 }
             }
 
@@ -94,15 +95,18 @@ public:
     };
     ~WriteLocker()
     {
+        apr_atomic_t *lock;
         apr_size_t try_count;
         apr_uint32_t curr_status;
         apr_uint32_t new_status;
 
-        try_count = 0;
+        lock = lock_;
+        try_count = 1;
         while (1) {
-            try_count++;
+            // curr_status の read がループ外に押し出されるのを防ぐ
+            MEMORY_BARRIER;
 
-            curr_status = apr_atomic_read(lock_);
+            curr_status = apr_atomic_read(lock);
             if (UNLIKELY(is_timeout(curr_status, status_))) {
                 // 他のスレッドにてタイムアウト処理がされた
                 log_try_count("WriteUnLock(TIME OUT)",
@@ -111,12 +115,13 @@ public:
             }
 
             new_status = curr_status & AGE_MASK;
-            if (apr_atomic_cas(lock_, new_status, curr_status) ==
+            if (apr_atomic_cas(lock, new_status, curr_status) ==
                 curr_status) {
                 log_try_count("WriteUnLock",
                               try_count, curr_status, new_status);
                 return;
             }
+            try_count++;
         }
     };
     static bool is_locked(apr_atomic_t *lock) {
