@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 2551M 2007-08-08 15:20:56Z (ローカル) $
+ * $Id: Auxiliary.cpp 2562 2007-08-18 08:56:57Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -49,7 +49,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2551M 2007-08-08 15:20:56Z (ローカル) $");
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2562 2007-08-18 08:56:57Z svn $");
 
 void init_atomic(apr_pool_t *pool)
 {
@@ -343,11 +343,12 @@ const char *size_str(apr_pool_t *pool, apr_uint64_t size)
     const char *unit_str;
     ldiv_t size_num;
 
-    // MEMO: 約 400 TB 以上だと桁あふれして誤動作るので注意
+    // MEMO: 約 400 TB 以上だと桁あふれして誤動するので注意
 
     do {
         if (size > (1024*1024*1024)) {
-            temp_size = static_cast<apr_size_t>(size / (1024*1024*1024/CMP_FACTOR));
+            temp_size = static_cast<apr_size_t>(size /
+                                                (1024*1024*1024/CMP_FACTOR));
             unit_str = GBYTE_UNIT;
             break;
         }
@@ -367,8 +368,7 @@ const char *size_str(apr_pool_t *pool, apr_uint64_t size)
 
     size_num = std::ldiv(temp_size * 10 / CMP_FACTOR, 10L);
 
-    return apr_psprintf(pool,
-                        "%ld.%ld %s",
+    return apr_psprintf(pool, "%ld.%ld %s",
                         size_num.quot, size_num.rem, unit_str);
 }
 
@@ -548,7 +548,7 @@ void show_usage(const char *prog_name)
 
 void run_size_str(apr_pool_t *pool)
 {
-    static const apr_size_t TEST_COUNT  = 100000;
+    static const apr_size_t TEST_COUNT  = 10000000;
     apr_uint64_t num;
     const char *str;
     const char *str_ref;
@@ -558,10 +558,10 @@ void run_size_str(apr_pool_t *pool)
     show_test_name("size_str");
 
     start_time = get_usage_sec();
-    for (uint32_t i = 0; i < TEST_COUNT; i++) {
+    for (apr_size_t i = 0; i < TEST_COUNT; i++) {
         num = rand();
-//         str = size_str(pool, num);
-        str_ref = size_str_ref(pool, num);
+        str = size_str(pool, num);
+//         str_ref = size_str_ref(pool, num);
 
 //         if (strcmp(str, str_ref)) {
 //             THROW(MESSAGE_BUG_FOUND);
