@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 2548 2007-08-06 14:16:57Z svn $
+ * $Id: TemplateExecutor.cpp 2560 2007-08-13 16:29:46Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -41,7 +41,7 @@
 using namespace std;
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2548 2007-08-06 14:16:57Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2560 2007-08-13 16:29:46Z svn $");
 #endif
 
 #ifdef DEBUG_TemplateExecutor
@@ -245,7 +245,7 @@ void TemplateExecutor<W>::exec_print_element(const node_t *node)
             if (var->s->l == 0) {
                 return print(var->s->s);
             } else {
-                return print(var->s->s);// , var->s->l);
+                return print(var->s->s , var->s->l);
             }
         } else {
             return print(calc_i_val(var));
@@ -578,7 +578,6 @@ TemplateExecutor<W>::get_variable(const node_t *node)
         if ((node->child.right->type == Parser::INTEGER) ||
             (node->child.right->type == Parser::IDENTIFIER)) { // foo[int]
             var = cont_var->v + calc_i_val(node->child.right);
-
         } else if (node->child.right->type == Parser::HASH_REF) { // foo[var].baz
             cont_var = cont_var->v + calc_i_val(node->child.right->child.left);
 #ifndef FASTEST
