@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ThumbnailIterator.cpp 2297 2006-12-24 03:13:15Z svn $
+ * $Id: ThumbnailIterator.cpp 2495 2007-07-05 13:53:44Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -32,22 +32,28 @@
 #include "apr.h"
 
 #include "ThumbnailIterator.h"
-#include "ThumbnailList.h"
+#include "UploadItemManager.h"
+#include "ReadLocker.h"
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ThumbnailIterator.cpp 2297 2006-12-24 03:13:15Z svn $");
+SOURCE_INFO_ADD("$Id: ThumbnailIterator.cpp 2495 2007-07-05 13:53:44Z svn $");
 
 /******************************************************************************
  * public メソッド
  *****************************************************************************/
 ThumbnailIterator::ThumbnailIterator(apr_pool_t *pool,
-                                     ThumbnailList *thumbnail_list,
+                                     UploadItemManager *item_manager,
                                      apr_size_t start_index,
                                      apr_size_t end_index)
   : thumbnail_list_(NULL),
     curr_index_(0)
 {
+    ThumbnailList *thumbnail_list;
+    ReadLocker manager_locker(item_manager->lock_);
+
+    thumbnail_list = item_manager->thumbnail_list_;
+
     validate_index(thumbnail_list, &start_index, &end_index);
     size_= end_index - start_index;
 
