@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 2501 2007-07-06 15:27:30Z svn $
+ * $Id: UploadItem.cpp 2501M 2007-08-19 14:24:32Z (ローカル) $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItem.cpp 2501 2007-07-06 15:27:30Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItem.cpp 2501M 2007-08-19 14:24:32Z (ローカル) $");
 
 #define AS_BCOMMENT(pointer)        reinterpret_cast<bbs_comment_t *>(pointer)
 #define UINT16(pointer)             static_cast<apr_uint16_t>(pointer)
@@ -122,6 +122,12 @@ UploadItem *UploadItem::get_instance(apr_pool_t *pool, apr_size_t item_id,
                         remove_pass, download_pass, comment, is_need_validate);
 }
 
+int UploadItem::cmp_download_count(const UploadItem *a, const UploadItem *b)
+{
+    return static_cast<int>(b->get_download_count()) -
+        static_cast<int>(a->get_download_count());
+}
+
 
 /******************************************************************************
  * private メソッド
