@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemListReader.cpp 2388 2007-03-10 11:34:50Z svn $
+ * $Id: UploadItemListReader.cpp 2556 2007-08-12 01:36:38Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,7 +44,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2388 2007-03-10 11:34:50Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2556 2007-08-12 01:36:38Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -148,71 +148,6 @@ bool UploadItemListReader::is_file_name_valid(const char *file_name)
     return (file_name[i] == '\0');
 }
 
-/******************************************************************************
- * テスト
- *****************************************************************************/
-#ifdef DEBUG_UploadItemListReader
-#include <memory>
-
-#include "apr_shm.h"
-
-#include "TestRunner.h"
-
-static const apr_size_t MAX_LIST_SIZE   = 1000;
-
-void show_usage(const char *prog_name)
-{
-    cerr << "Usage: " << prog_name << " <DAT_DIR_PATH>" << endl;
-}
-
-static void run_sort_by_mtime(UploadItemList *item_list)
-{
-    show_test_name("sort by mtime");
-}
-
-void run_all(apr_pool_t *pool, int argc, const char * const *argv)
-{
-    const char *data_dir_path;
-    apr_shm_t *shm;
-    apr_size_t dump_level;
-
-    if (argc == 1) {
-        THROW(MESSAGE_ARGUMENT_INVALID);
-    }
-
-    data_dir_path = argv[1];
-    if (argc >= 3) {
-        dump_level = atoi(argv[2]);
-    } else {
-        dump_level = 0;
-    }
-
-    if (!File::is_exist(pool, data_dir_path)) {
-        THROW(MESSAGE_DATA_DIR_NOT_FOUND);
-    }
-
-    shm = create_shm(pool, UploadItemList::get_memory_size(MAX_LIST_SIZE));
-
-    UploadItemList *item_list = UploadItemListReader::read(pool, data_dir_path,
-                                                           shm, MAX_LIST_SIZE);
-
-    show_item("data_dir", data_dir_path);
-    show_item("manager memory",
-              UploadItemList::get_memory_size(MAX_LIST_SIZE) /
-              static_cast<double>(1024), " KB");
-    show_line();
-
-    if (dump_level > 2) {
-        show_test_name("read");
-        UploadItemList::dump_header_list(pool, item_list);
-        show_line();
-    }
-
-    run_sort_by_mtime(item_list);
-}
-
-#endif
-
 // Local Variables:
 // mode: c++
 // coding: utf-8-dos
