@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: cgi_uploader.cpp 2540 2007-07-21 15:21:47Z svn $
+ * $Id: cgi_uploader.cpp 2561 2007-08-13 18:56:01Z svn $
  *****************************************************************************/
 
 /**
@@ -43,14 +43,15 @@
 
 #include "CGIResponse.h"
 #include "UploaderConfigReader.h"
+#include "TemporaryPool.h"
 #include "SourceInfo.h"
 
 #define TEMPLATE_INSTANTIATION
 #include "uploader_handler.cpp"
 
-SOURCE_INFO_ADD("$Id: cgi_uploader.cpp 2540 2007-07-21 15:21:47Z svn $");
+SOURCE_INFO_ADD("$Id: cgi_uploader.cpp 2561 2007-08-13 18:56:01Z svn $");
 
-// #define BENCHMARK 100
+#define BENCHMARK 50000
 
 // strace したときに，表示処理の範囲を見分けるための印
 #ifdef __linux__
@@ -62,7 +63,6 @@ SOURCE_INFO_ADD("$Id: cgi_uploader.cpp 2540 2007-07-21 15:21:47Z svn $");
 int main(int argc, const char * const *argv)
 {
     apr_pool_t *pool;
-    apr_pool_t *handler_pool;
     const char *arg;
     UploaderConfig *config;
     int status;
@@ -91,21 +91,19 @@ int main(int argc, const char * const *argv)
 
         STRACE_MARKER();
 #ifdef BENCHMARK
-        for (apr_size_t i = 0; i < BENCHMARK; ++i) {
+        for (apr_size_t i = 0; i < BENCHMARK; i++)
 #endif
-            apr_pool_create(&handler_pool, NULL);
-            CGIResponse::Handle handle(pool);
+        {
+            TemporaryPool temp_pool(pool);
+            CGIResponse::Handle handle(temp_pool.get());
 
             status = uploader_command_handler<CGIResponse>
                 (&handle, config, arg);
-
-            apr_pool_destroy(handler_pool);
-#ifdef BENCHMARK
         }
-#endif
         STRACE_MARKER();
 
         config->finalize();
+        apr_pool_destroy(pool);
         apr_terminate();
 
         return status;
@@ -118,6 +116,7 @@ int main(int argc, const char * const *argv)
         if (config != NULL) {
             config->finalize();
         }
+        apr_pool_destroy(pool);
         apr_terminate();
 
         return EXIT_FAILURE;
